@@ -157,6 +157,12 @@ class TestMixmaster(unittest.TestCase):
         output_df['value'] = output_df['value'].astype('str')
         output_df['feature'] = output_df['feature'].astype('str')
 
+        with open('mixed.json','w') as f:
+            f.write(json.dumps(dct))
+
+        df.to_csv('test3-mixed.csv',index=False)
+        output_df.to_csv('test3-expected.csv', index=False)
+
         # Assertions
         assert_frame_equal(df, output_df, check_categorical = False)
         assert_dict_equal(dct, output_dict)
